.. toctree::
    :hidden:

    Home <home>
    intro
    basic-usage
    other-bidict-types
    other-functionality
    addendum
    changelog
    api
    contributors-guide
    code-of-conduct

.. include:: home.rst
